Package: joinpointR
Type: Package
Title: Tidy Tools for Joinpoint Regression Models
Version: 1.0.0
Authors@R: 
    person(
        "Tamara", "Ricardo", , 
        email ="tamararicardo83@gmail.com", 
        role = c("aut", "cre"),
        comment = c(ORCID = "0000-0002-0921-2611"))
Description: Provides tools to fit joinpoint regression models with a log-linear 
    specification by levels of a categorical variable. The package acts as a 
    wrapper around the 'segmented' package, facilitating model fitting, selection, 
    and interpretation. It includes functions to estimate the Annual Percent Change 
    (APC) and the Average Annual Percent Change (AAPC), along with their 95% 
    confidence intervals, and to generate formatted summary tables and plots of results.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: dplyr, purrr, tidyr, tibble, ggplot2, segmented, scales,
        flextable, rlang, stringr, stats, officer, forcats, cols4all
URL: https://github.com/datos-ine/joinpointR
BugReports: https://github.com/datos-ine/joinpointR/issues
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
VignetteBuilder: knitr
Depends: R (>= 4.1.0)
LazyData: true
NeedsCompilation: no
Packaged: 2026-06-10 16:03:54 UTC; user
Author: Tamara Ricardo [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0921-2611>)
Maintainer: Tamara Ricardo <tamararicardo83@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-10 17:10:08 UTC
Built: R 4.5.2; ; 2026-06-10 21:22:19 UTC; unix
