# Generated by roxygen2: do not edit by hand

export(get_aapc)
export(get_apc)
export(gg_jpoint)
export(jp_to_ft)
export(model_jp)
export(summary_jp)
importFrom(dplyr,where)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(utils,head)
importFrom(utils,tail)
