#' @importFrom rlang .data :=
NULL

utils::globalVariables(
  c(
    "APC",
    "CI",
    "CI_l",
    "CI_u",
    "lci",
    "uci",
    "Period",
    "group",
    "obs",
    "jp",
    "facets",
    "fit"
  )
)

#' @importFrom dplyr where
#' @importFrom utils head tail
NULL
