% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_jp.R
\name{summary_jp}
\alias{summary_jp}
\title{Summary Table For Joinpoint Regression Models}
\usage{
summary_jp(
  mods,
  digits = 1,
  var1 = "group",
  var2 = "subgroup",
  ft = FALSE,
  lan = c("en", "es")
)
}
\arguments{
\item{mods}{List of joinpoint regression models (model_jp() output).}

\item{digits}{Number of decimal places to display (integer).}

\item{var1}{Character. Name of the grouping variable.}

\item{var2}{Character. Name of the subgrouping variable (optional).}

\item{ft}{Logical. If TRUE returns a flextable object, if FALSE returns a tibble.}

\item{lan}{Language of output: "en" (English) or "es" (Spanish).}
}
\value{
A tibble or a flextable object.
}
\description{
Generates a table displaying the number of joinpoints, time breaks, APC and its 95\% confidence
interval, and AAPC and its statistical significance from a list of joinpoint models.
}
\examples{
library(dplyr)
# Load example data
data("plant", package = "segmented")

names(plant)

# Fit the joinpoint models
mods <- model_jp(data = plant, value = "y", time = "time", group = "group", k = 2, test = TRUE)

summary_jp(mods, digits = 1, var1 = "group", ft = FALSE, lan = "en")
}
\author{
Tamara Ricardo
}
