% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_apc.R
\name{get_apc}
\alias{get_apc}
\title{Annual Percent Change by Segment (APC)}
\usage{
get_apc(mod, digits = 1, time = "time", dec = ".")
}
\arguments{
\item{mod}{Joinpoint regression model (segmented object).}

\item{digits}{Number of decimal places to display (integer).}

\item{time}{Time variable used in the model (character).}

\item{dec}{Character. Decimal separator to use (e.g., "." or ",").}
}
\value{
A character vector with APC and 95\% CI for each segment.
}
\description{
Calculates the Annual Percent Change (APC) for each segment and its 95\%
confidence interval.
}
\examples{
# Load example data
data("plant", package = "segmented")

names(plant)

# Fit the joinpoint models
mods <- model_jp(data = plant, value = "y", time = "time", group = "group", k = 2, test = TRUE)

# Obtain APC (95\% CI)
get_apc(mods$RKW, digits = 1, time = "time", dec = ".")
}
\author{
Tamara Ricardo
}
